@@ -99,6 +99,8 @@ arfima <- function(x, drange = c(0, 0.5), estim = c("mle","ls"), lambda=NULL, ..
 		p <- length(fit$ar)
 		q <- length(fit$ma)
 		fit2 <- try(Arima(y,order=c(p,0,q),include.mean=FALSE))
+		if(class(fit2) == "try-error")
+			fit2 <- try(Arima(y,order=c(p,0,q),include.mean=FALSE,method="ML"))
 		if(class(fit2) != "try-error")
 		{
 			if(p>0)
