@@ -15,16 +15,14 @@ auto.arima <- function(x, d=NA, D=NA, max.p=5, max.q=5,
     parallel <- FALSE
   }
 
+  series <- deparse(substitute(x))
 
   # Check for constant data
-  # arbitrary small constant added to scaling denominator to avoid problem of all zeros
-  # Very unlikely for all values to be equal to -.039483049578.
-  cv <- var(x,na.rm=TRUE) / mean(abs(x+.039483049578),na.rm=TRUE)
-  if(cv < 1e-10) # Data are essentially constant
+  if(is.constant(x))
   {
     fit <- Arima(x,order=c(0,0,0),fixed=mean(x,na.rm=TRUE))
     fit$x <- x
-    fit$series <- deparse(substitute(x))
+    fit$series <- series
     fit$call <- match.call()
     fit$call$x <- data.frame(x=x)
     return(fit)
@@ -80,6 +78,22 @@ auto.arima <- function(x, d=NA, D=NA, max.p=5, max.q=5,
     dx <- xx
   if(is.na(d))
     d <- ndiffs(dx,test=test)
+  if(d>0)
+    dx <- diff(dx,differences=d,lag=1)
+
+  if(is.constant(dx))
+  {
+    if(D>0)
+      fit <- Arima(x,order=c(0,d,0),seasonal=list(order=c(0,D,0),period=m), fixed=mean(dx,na.rm=TRUE), include.constant=TRUE)
+    else
+      fit <- Arima(x,order=c(0,d,0),fixed=mean(dx,na.rm=TRUE),include.constant=TRUE)
+    fit$x <- x
+    fit$series <- series
+    fit$call <- match.call()
+    fit$call$x <- data.frame(x=x)
+    return(fit)
+  }
+
 
   if(m > 1)
   {
@@ -114,7 +128,7 @@ auto.arima <- function(x, d=NA, D=NA, max.p=5, max.q=5,
     bestfit$call$x <- data.frame(x=x)
     bestfit$lamba <- lambda
     bestfit$x <- orig.x
-    bestfit$series <- deparse(substitute(x))
+    bestfit$series <- series
     bestfit$fitted <- fitted(bestfit)
     if(!is.null(lambda))
     {
@@ -359,7 +373,7 @@ auto.arima <- function(x, d=NA, D=NA, max.p=5, max.q=5,
   # Return best fit
 
   bestfit$x <- orig.x
-  bestfit$series <- deparse(substitute(x))
+  bestfit$series <- series
   bestfit$ic <- NULL
   bestfit$call <- match.call()
   bestfit$call$x <- data.frame(x=x)
@@ -522,7 +536,11 @@ summary.Arima <- function(object,...)
 # Number of seasonal differences
 nsdiffs <- function(x, m=frequency(x), test=c("ocsb", "ch"))
 {
-    test <- match.arg(test)
+
+  if(is.constant(x))
+    return(0)
+
+  test <- match.arg(test)
     if(m==1)
             stop("Non seasonal data")
     else if(m < 1)
@@ -608,22 +626,21 @@ OCSBtest <- function(time.series, period)
                 if(class(regression) == "try-error" | tryCatch(any(is.nan(sqrt(diag(regression$var.coef)))), error=function(e) TRUE))
                 {
                     regression <- try(lm(contingent.series ~ y.one + y.two - 1, na.action=NULL), silent=TRUE)
-                    if(class(regression) == "try-error")
-                      return(0) # Give up
-                    if(is.na(sum(regression$coeff)))
-                      return(0) # Some problem, probably due to not enough data, so give up.
                     reg.summary <- summary(regression)
-                    t.two <- reg.summary$coefficients[2,3]
+                    reg.coefs <- reg.summary$coefficients
+                    t.two.pos <- grep("t.two", rownames(reg.coefs), fixed = TRUE)
+                    if(length(t.two.pos) != 0)
+                      t.two <- reg.coefs[t.two.pos,3]
+                    else
+                      t.two <- NA
 
                     ###Re-enable warnings
                     options(warn=old.warning.level)
 
                     if((is.nan(t.two)) | (is.infinite(t.two)) | (is.na(t.two)) | (class(regression) == "try-error"))
-                    {
-                        return(1)
-                    }
+                      return(1)
                     else
-                        return(as.numeric(t.two >= calcOCSBCritVal(period)))
+                      return(as.numeric(t.two >= calcOCSBCritVal(period)))
                 }
             }
         }
@@ -635,3 +652,10 @@ OCSBtest <- function(time.series, period)
 	options(warn=old.warning.level)
     return(as.numeric(t.two >= calcOCSBCritVal(period)))
 }
+
+is.constant <- function(x)
+{
+  y <- rep(x[1],length(x))
+  identical(c(x),y)
+}
+
